@@ -1,5 +1,5 @@
 "f2flo" <-
-function(f, pp=NA, xlo=NULL) {
+function(f, pp=NA, xlo=NULL, type=c("ge", "gt")) {
    if(! check.fs(f)) return(FALSE)
    if(! is.null(xlo)) pp <- xlo$pp
    if(is.na(pp)) {
@@ -11,7 +11,12 @@ function(f, pp=NA, xlo=NULL) {
         return(FALSE)
       }
    }
-   f  <- f[f >= pp]
+   type <- match.arg(type)
+   if(type == "gt") {
+     f <- f[f >  pp] # see identifical subsetting in f2f
+   } else {
+     f <- f[f >= pp] # see identifical subsetting in f2f
+   }
    zs <- (f-pp)/(1-pp)
    if(any(zs < 0) || any(zs > 1)) {
       warning("invalid nonexceedance probability after pp conditioning")
