@@ -8,6 +8,7 @@ function(lmr=NULL,
       noglo=FALSE,
       nogpa=FALSE,
       nope3=FALSE,
+      nopdq3=FALSE,
       nogno=FALSE,
       nogov=FALSE,
       nocau=TRUE,
@@ -20,7 +21,7 @@ function(lmr=NULL,
          xlab="L-SKEW",
          ylab="L-KURTOSIS",
          add=FALSE, empty=FALSE,
-         autolegend=FALSE,xleg=NULL,yleg=NULL,
+         autolegend=FALSE, xleg=NULL, yleg=NULL, legendcex=0.9,
          ...) {
 
    entries <- vector(mode = "character")
@@ -38,7 +39,7 @@ function(lmr=NULL,
    if(empty) return("empty")
 
    if(! nolimits) {
-     lines(lmr$limits,lwd=2,col=8)
+     lines(lmr$limits, lwd=2, col=8)
      entryi <- entryi + 1
      entries[entryi] <- "Theoretical limits"
      Elwd[entryi] <- 2
@@ -49,21 +50,21 @@ function(lmr=NULL,
    }
    if(! nolines) {
      if(! noaep4) {
-        lines(lmr$aep4, col="red", lty=3)
+        lines(lmr$aep4, col="red", lty=4)
         entryi <- entryi + 1
         entries[entryi] <- "AEP4"
         Elwd[entryi] <- 1
-        Ecol[entryi] <- 2
+        Ecol[entryi] <- "red"
         Epch[entryi] <- NA
         Elty[entryi] <- 4
         Ecex[entryi] <- 1
      }
      if(! nogev) {
-        lines(lmr$gev, col="red",lty=2)
+        lines(lmr$gev, col="red", lty=2)
         entryi <- entryi + 1
         entries[entryi] <- "GEV"
         Elwd[entryi] <- 1
-        Ecol[entryi] <- 2
+        Ecol[entryi] <- "red"
         Epch[entryi] <- NA
         Elty[entryi] <- 2
         Ecex[entryi] <- 1
@@ -73,7 +74,7 @@ function(lmr=NULL,
         entryi <- entryi + 1
         entries[entryi] <- "GLO"
         Elwd[entryi] <- 1
-        Ecol[entryi] <- 3
+        Ecol[entryi] <- "green"
         Epch[entryi] <- NA
         Elty[entryi] <- 1
         Ecex[entryi] <- 1
@@ -83,7 +84,7 @@ function(lmr=NULL,
         entryi <- entryi + 1
         entries[entryi] <- "GNO"
         Elwd[entryi] <- 1
-        Ecol[entryi] <- 4
+        Ecol[entryi] <- "blue"
         Epch[entryi] <- NA
         Elty[entryi] <- 2
         Ecex[entryi] <- 1
@@ -103,7 +104,7 @@ function(lmr=NULL,
         entryi <- entryi + 1
         entries[entryi] <- "GPA"
         Elwd[entryi] <- 1
-        Ecol[entryi] <- 4
+        Ecol[entryi] <- "blue"
         Epch[entryi] <- NA
         Elty[entryi] <- 1
         Ecex[entryi] <- 1
@@ -118,74 +119,84 @@ function(lmr=NULL,
         Elty[entryi] <- 1
         Ecex[entryi] <- 1
      }
+     if(! nopdq3) {
+        lines(lmr$pdq3, col="darkgreen", lty=2)
+        entryi <- entryi + 1
+        entries[entryi] <- "PDQ3"
+        Elwd[entryi] <- 1.3
+        Ecol[entryi] <- "darkgreen"
+        Epch[entryi] <- NA
+        Elty[entryi] <- 2
+        Ecex[entryi] <- 1
+     }
    }
    if(! nopoints) {
      if(! nocau) {
-        points(lmr$cau,pch=13,col="green",cex=1.25)
+        points(lmr$cau, pch=13, col="green", cex=1.25)
         entryi <- entryi + 1
         entries[entryi] <- "CAU (limiting TL1)"
         Elwd[entryi] <- NA
-        Ecol[entryi] <- 3
+        Ecol[entryi] <- "green"
         Epch[entryi] <- 13
         Elty[entryi] <- NA
         Ecex[entryi] <- 1.25
      }
      if(! noexp) {
-        points(lmr$exp,pch=16,col="red",cex=1.5)
+        points(lmr$exp, pch=16, col="red", cex=1.5)
         entryi <- entryi + 1
         entries[entryi] <- "EXP"
         Elwd[entryi] <- NA
-        Ecol[entryi] <- 2
+        Ecol[entryi] <- "red"
         Epch[entryi] <- 16
         Elty[entryi] <- NA
         Ecex[entryi] <- 1.5
      }
      if(! nonor) {
-        points(lmr$nor,pch=15,col="red",cex=1.5)
+        points(lmr$nor, pch=15, col="red", cex=1.5)
         entryi <- entryi + 1
         entries[entryi] <- "NOR"
         Elwd[entryi] <- NA
-        Ecol[entryi] <- 2
+        Ecol[entryi] <- "red"
         Epch[entryi] <- 15
         Elty[entryi] <- NA
         Ecex[entryi] <- 1.5
      }
      if(! nogum) {
-        points(lmr$gum,pch=17,col="red",cex=1.5)
+        points(lmr$gum, pch=17, col="red", cex=1.5)
         entryi <- entryi + 1
         entries[entryi] <- "GUM"
         Elwd[entryi] <- NA
-        Ecol[entryi] <- 2
+        Ecol[entryi] <- "red"
         Epch[entryi] <- 17
         Elty[entryi] <- NA
         Ecex[entryi] <- 1.5
      }
      if(! noray) {
-        points(lmr$ray,pch=18,col="red",cex=1.5)
+        points(lmr$ray, pch=18, col="red", cex=1.5)
         entryi <- entryi + 1
         entries[entryi] <- "RAY"
         Elwd[entryi] <- NA
-        Ecol[entryi] <- 2
+        Ecol[entryi] <- "red"
         Epch[entryi] <- 18
         Elty[entryi] <- NA
         Ecex[entryi] <- 1.5
      }
      if(! nosla) {
-        points(lmr$sla,pch=10,cex=1.25,col="green")
+        points(lmr$sla, pch=10, cex=1.25, col="green")
         entryi <- entryi + 1
         entries[entryi] <- "SLA (TL1)"
         Elwd[entryi] <- NA
-        Ecol[entryi] <- 3
+        Ecol[entryi] <- "green"
         Epch[entryi] <- 10
         Elty[entryi] <- NA
         Ecex[entryi] <- 1.25
      }
      if(! nouni) {
-        points(lmr$uniform,pch=12,cex=1.25,col="red")
+        points(lmr$uniform, pch=12, cex=1.25, col="red")
         entryi <- entryi + 1
         entries[entryi] <- "UNI"
         Elwd[entryi] <- NA
-        Ecol[entryi] <- 2
+        Ecol[entryi] <- "red"
         Epch[entryi] <- 12
         Elty[entryi] <- NA
         Ecex[entryi] <- 1.25
@@ -193,15 +204,25 @@ function(lmr=NULL,
    }
 
    if(autolegend == TRUE & length(entries) > 0) {
-     if(is.null(xleg)) warning("xleg is NULL, but needed")
-     if(is.null(yleg)) warning("yleg is NULL, but needed")
+     if(is.character(xleg)) {
+       legend(xleg, entries,
+              lwd=Elwd,
+              col=Ecol,
+              pch=Epch,
+              lty=Elty,
+              pt.cex=Ecex,
+              xjust=0.5, bty="n", cex=legendcex)
+     } else {
+       if(is.null(xleg)) warning("xleg is NULL, but needed")
+       if(is.null(yleg)) warning("yleg is NULL, but needed")
 
-     legend(xleg,yleg,entries,
-            lwd=Elwd,
-            col=Ecol,
-            pch=Epch,
-            lty=Elty,
-            pt.cex=Ecex,
-            xjust=0.5,bty="n",cex=0.9)
+       legend(xleg, yleg, entries,
+              lwd=Elwd,
+              col=Ecol,
+              pch=Epch,
+              lty=Elty,
+              pt.cex=Ecex,
+              xjust=0.5, bty="n", cex=legendcex)
+     }
    }
 }
